
# API Overview

## Modules

- [`lazydocs.generation`](./lazydocs.generation.md#module-lazydocsgeneration): Main module for markdown generation.

## Classes

- [`MarkdownGenerator`](./lazydocs.generation.md#class-markdowngenerator): Markdown generator class.

## Functions

- [`generate_docs`](./lazydocs.generation.md#function-generate_docs): Generates markdown documentation for provided paths based on Google-style docstrings.
- [`to_md_file`](./lazydocs.generation.md#function-to_md_file): Creates an API docs file from a provided text.

---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs) on 16 Nov 2020._
